package DateTime;
##############################################################################
# Limited DateTime for XML::Atom
# 2004-06-26 by makamaka [at] donzoko.net
##############################################################################

use Time::Local;

use overload ( 'fallback' => 1,
	qw/""/ => 'iso8601',
);

sub new{
	my $class = shift;
	my %args  = @_;
	bless \%args, $class;
}

sub now{
	my $self = shift;
	@$self{qw(second minute hour day month year)}
	    = ( gmtime( time ) )[ 0..5 ];
	$self->{year} += 1900;
	$self->{month}++;
	$self;
}

sub iso8601{
	my $self = shift;
	my ($year,$mon,$day,$hour,$min,$sec)
	  = @$self{qw(year month day hour minute second)};

	for( $hour,$min,$sec ){
		$_ = 0 unless(defined $_);
	}

	sprintf("%04d-%02d-%02dT%02d:%02d:%02d",$year,$mon,$day,$hour,$min,$sec);
}

sub subtract{
	my $self   = shift;
	my %args   = @_;
	my $offset = $args{seconds};
	my ($year,$mon,$day,$hour,$min,$sec) = @$self{qw(year month day hour minute second)};
	my $time = Time::Local::timelocal($sec,$min,$hour,$day,$mon-1,$year-1900);

	($sec,$min,$hour,$day,$mon,$year) = localtime( $time - $offset );

	@$self{qw(year month day hour minute second)}
	    = ($year+1900,$mon+1,$day,$hour,$min,$sec);

	$self;
}

##############################################################################
package DateTime::TimeZone;

sub offset_as_seconds{
	my ($sign,$h,$s) = $_[0] =~ /([+-])(\d\d):(\d\d)/;
	my $offset = $h * 3600 + $s * 60;
	$offset *= -1 if($sign eq '-');
	$offset;
}

1;
